<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:fo="http://www.w3.org/1999/XSL/Format" version="1.0">
  <xsl:import href="library.xsl"/>
  <xsl:import href="language.xsl"/>
  <xsl:import href="attributeset.xsl"/>
  <xsl:variable name="year" select="substring(/document/head/date, 0, 5)"/>
  <xsl:variable name="lng" select="/document/head/document-language/text()"/>
  <xsl:variable name="dstat" select="/document/head/document-type/text()"/>
  <xsl:template name="layoutmaster">
    <fo:layout-master-set>
      <fo:simple-page-master master-name="title" xsl:use-attribute-sets="pagedefault">
        <fo:region-body margin-top="16pt" margin-bottom="16pt"/>
        <fo:region-before extent="54pt"/>
        <fo:region-after extent="51pt"/>
      </fo:simple-page-master>
      <fo:simple-page-master master-name="top" xsl:use-attribute-sets="pagedefault">
        <fo:region-body margin-top="54pt" margin-bottom="51pt"/>
        <fo:region-before region-name="tophead" extent="54pt"/>
        <fo:region-after region-name="oddfoot" extent="51pt"/>
      </fo:simple-page-master>
      <fo:simple-page-master master-name="odd" xsl:use-attribute-sets="pagedefault"
        margin-left="45pt" margin-right="40pt">
        <fo:region-body margin-top="54pt" margin-bottom="51pt"/>
        <fo:region-before region-name="oddhead" extent="54pt"/>
        <fo:region-after region-name="oddfoot" extent="51pt"/>
      </fo:simple-page-master>
      <fo:simple-page-master master-name="even" xsl:use-attribute-sets="pagedefault">
        <fo:region-body margin-top="54pt" margin-bottom="51pt"/>
        <fo:region-before region-name="evenhead" extent="54pt"/>
        <fo:region-after region-name="evenfoot" extent="51pt"/>
      </fo:simple-page-master>
      <fo:simple-page-master master-name="backeven" xsl:use-attribute-sets="pagedefault">
        <fo:region-body margin-top="54pt" margin-bottom="51pt"/>
        <fo:region-before region-name="evenhead" extent="54pt"/>
        <fo:region-after region-name="backevenfoot" extent="51pt"/>
      </fo:simple-page-master>
      <fo:page-sequence-master master-name="prev">
        <fo:repeatable-page-master-alternatives>
          <fo:conditional-page-master-reference master-reference="title" page-position="first"/>
          <fo:conditional-page-master-reference master-reference="odd" odd-or-even="odd"/>
          <fo:conditional-page-master-reference master-reference="even" odd-or-even="even"/>
        </fo:repeatable-page-master-alternatives>
      </fo:page-sequence-master>
      <fo:page-sequence-master master-name="stdex">
        <fo:repeatable-page-master-alternatives>
          <fo:conditional-page-master-reference master-reference="top" page-position="first"/>
          <fo:conditional-page-master-reference master-reference="odd" odd-or-even="odd"/>
          <fo:conditional-page-master-reference master-reference="even" odd-or-even="even"/>
        </fo:repeatable-page-master-alternatives>
      </fo:page-sequence-master>
      <fo:page-sequence-master master-name="back">
        <fo:repeatable-page-master-alternatives>
          <fo:conditional-page-master-reference master-reference="title" page-position="first"/>
          <fo:conditional-page-master-reference master-reference="backeven" odd-or-even="even"/>
        </fo:repeatable-page-master-alternatives>
      </fo:page-sequence-master>
    </fo:layout-master-set>
  </xsl:template>
  <xsl:template name="headfoot">
    <xsl:variable name="headcode">
      <xsl:call-template name="refnum"/>
    </xsl:variable>
    <xsl:variable name="cpyright">&#169; <xsl:value-of select="substring-before($dcode, ' ')"
        /><xsl:text> </xsl:text><xsl:value-of select="$year"/> &#8211; <xsl:call-template
        name="rightstr">
        <xsl:with-param name="lang" select="$lng"/>
      </xsl:call-template></xsl:variable>
    <fo:static-content flow-name="tophead">
      <fo:block-container width="510pt" height="10mm" top="0pt" position="absolute"
        border-width="2pt" border-top-style="solid" border-bottom-style="solid">
        <fo:block xsl:use-attribute-sets="default" font-size="11pt" text-align="start"
          font-weight="bold" line-height="10mm">
          <xsl:call-template name="docstat">
            <xsl:with-param name="status" select="$dstat"/>
            <xsl:with-param name="lang" select="$lng"/>
          </xsl:call-template>
        </fo:block>
      </fo:block-container>
      <fo:block-container width="510pt" height="10mm" top="0pt" position="absolute">
        <fo:block xsl:use-attribute-sets="default" font-size="11pt" text-align="end"
          font-weight="bold" line-height="10mm">
          <xsl:value-of select="$headcode"/>
        </fo:block>
      </fo:block-container>
    </fo:static-content>
    <fo:static-content flow-name="oddhead">
      <fo:block xsl:use-attribute-sets="default" font-size="11pt" font-weight="bold"
        text-align="end">
        <xsl:value-of select="$headcode"/>
      </fo:block>
    </fo:static-content>
    <fo:static-content flow-name="evenhead">
      <fo:block xsl:use-attribute-sets="default" font-size="11pt" font-weight="bold"
        text-align="start">
        <xsl:value-of select="$headcode"/>
      </fo:block>
    </fo:static-content>
    <fo:static-content flow-name="oddfoot">
      <fo:block-container width="510pt" height="51pt" top="43pt" position="absolute"
        display-align="after">
        <fo:block xsl:use-attribute-sets="default" font-size="8pt" text-align="start"
          line-height="8pt">
          <xsl:value-of select="$cpyright"/>
        </fo:block>
      </fo:block-container>
      <fo:block-container width="510pt" height="51pt" top="40pt" position="absolute"
        display-align="after">
        <fo:block xsl:use-attribute-sets="default" font-size="11pt" text-align="end"
          line-height="11pt">
          <fo:page-number/>
        </fo:block>
      </fo:block-container>
    </fo:static-content>
    <fo:static-content flow-name="evenfoot">
      <fo:block-container width="510pt" height="20pt" top="43pt" position="absolute"
        display-align="after">
        <fo:block xsl:use-attribute-sets="default" font-size="8pt" text-align="end">
          <xsl:value-of select="$cpyright"/>
        </fo:block>
      </fo:block-container>
      <fo:block-container width="510pt" height="20pt" top="40pt" position="absolute"
        display-align="after">
        <fo:block xsl:use-attribute-sets="default" font-size="11pt" text-align="start">
          <fo:page-number/>
        </fo:block>
      </fo:block-container>
    </fo:static-content>
    <fo:static-content flow-name="backevenfoot">
      <fo:block-container width="510pt" height="51pt" top="23pt" position="absolute"
        display-align="after">
        <fo:block xsl:use-attribute-sets="default" font-size="8pt" text-align="start"
          line-height="8pt">
          <xsl:value-of select="$cpyright"/>
        </fo:block>
      </fo:block-container>
    </fo:static-content>
    <fo:static-content flow-name="xsl-footnote-separator">
      <fo:block text-align-last="justify">
        <fo:leader leader-pattern="rule" rule-thickness="0.5pt" leader-length="33%"/>
      </fo:block>
    </fo:static-content>
  </xsl:template>
</xsl:stylesheet>
